# apypie - Apipie bindings for Python

[![Build Status](https://travis-ci.com/Apipie/apypie.svg?branch=master)](https://travis-ci.com/Apipie/apypie)
[![codecov](https://codecov.io/gh/Apipie/apypie/branch/master/graph/badge.svg)](https://codecov.io/gh/Apipie/apypie)
[![Documentation Status](https://readthedocs.org/projects/apypie/badge/?version=latest)](https://apypie.readthedocs.io/en/latest/?badge=latest)
